@@ -7,7 +7,7 @@ use warnings;
 use Carp 'croak';
 use Time::HiRes qw( time sleep );
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 sub _input_handler {
     my ( $input, $set ) = ( {}, {} );
@@ -42,7 +42,12 @@ sub _input_handler {
     my $singleton;
 
     sub new {
-        return $singleton if ($singleton);
+        if ($singleton) {
+            my $input = _input_handler(@_);
+            $singleton->{$_} = $input->{$_} for ( keys %$input );
+            return $singleton;
+        }
+
         shift;
 
         my $self = bless( _input_handler(@_), __PACKAGE__ );
@@ -99,8 +104,12 @@ sub now {
 }
 
 sub last {
-    my ( $self, $label ) = @_;
-    return ( defined $label ) ? $self->{$label}{last} : $self->history( undef, 1 )->[0]{time};
+    my ( $self, $label, $time ) = @_;
+
+    my $value_ref = ( defined $label ) ? \$self->{$label}{last} : \$self->history( undef, 1 )->[0]{time};
+    $$value_ref = $time if ( defined $time );
+
+    return $$value_ref;
 }
 
 sub history {
@@ -113,6 +122,24 @@ sub history {
     return $history;
 }
 
+sub sub {
+    my ( $self, $label, $sub ) = @_;
+
+    my $value_ref = ( defined $label ) ? \$self->{$label}{do} : \$self->history( undef, 1 )->[0]{do};
+    $$value_ref = $sub if ( ref $sub eq 'CODE' );
+
+    return $$value_ref;
+}
+
+sub wait {
+    my ( $self, $label, $wait ) = @_;
+
+    my $value_ref = ( defined $label ) ? \$self->{$label}{wait} : \$self->history( undef, 1 )->[0]{wait};
+    $$value_ref = $wait if ( defined $wait );
+
+    return $$value_ref;
+}
+
 1;
 
 __END__
@@ -127,7 +154,7 @@ Time::DoAfter - Wait before doing by label contoller singleton
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Time-DoAfter.svg)](https://travis-ci.org/gryphonshafer/Time-DoAfter)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Time-DoAfter/badge.png)](https://coveralls.io/r/gryphonshafer/Time-DoAfter)
@@ -154,12 +181,19 @@ version 1.03
 
     my ( $time_since, $time_wait ) = $tda1->do( sub {} );
 
-    my $current_time = $tda0->now;
-    my $last_time    = $tda0->last('label');
+    my $current_time   = $tda0->now;
+    my $last_time      = $tda0->last('label');
+    my $new_last_time  = $tda0->last( 'label', time );
 
-    my $all_history   = $tda0->history;
-    my $label_history = $tda0->history('label');
-    my $last_5_label  = $tda0->history( 'label', 5 );
+    my $all_history    = $tda0->history;
+    my $label_history  = $tda0->history('label');
+    my $last_5_label   = $tda0->history( 'label', 5 );
+
+    my $label_sub      = $tda0->sub('label');
+    my $new_label_sub  = $tda0->sub( 'label', sub {} );
+
+    my $label_wait     = $tda0->wait('label');
+    my $new_label_wait = $tda0->wait( 'label', [ 1.3, 2.1 ] );
 
 =head1 DESCRIPTION
 
@@ -250,6 +284,11 @@ the last "do" was done for a given label.
 
     my $last_time = $tda->last('things');
 
+C<last> can also act as a setter. If you pass in a time value, it will set the
+last time of the label to that time.
+
+    $tda->last( 'things', time );
+
 =head2 history
 
 After calling C<do> a few times, this library will build up a history of doing
@@ -265,6 +304,20 @@ You can also specify the number of most recent history events to return.
     my $last_thing      = pop @$last_5_things;
     my $last_thing_when = $last_thing->{time};
 
+=head2 sub
+
+Gets or sets the subroutine reference for a label's do action.
+
+    my $label_sub     = $tda0->sub('label');
+    my $new_label_sub = $tda0->sub( 'label', sub {} );
+
+=head2 wait
+
+Gets or sets the wait time (explicit value or arrayref of range) for a label.
+
+    my $label_wait     = $tda0->wait('label');
+    my $new_label_wait = $tda0->wait( 'label', [ 1.3, 2.1 ] );
+
 =head1 How Time Works
 
 If you specify a time to wait that's an integer or floating point, that value
